==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/ReferredToIdentifierAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferredToClassInAssocSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.AttributeReferenceInClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ClassIdentifierAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferredToIdentifierAttribute;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferredToIdentifierAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.AttributeReferenceInClassSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ClassIdentifierAttributeSetImpl;

import java.util.Arrays;
import java.util.List;


public class ReferredToIdentifierAttributeSetImpl extends InstanceSet<ReferredToIdentifierAttributeSet,ReferredToIdentifierAttribute> implements ReferredToIdentifierAttributeSet {

    // attributes
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) referredtoidentifierattribute.setAttr_ID( ref_Attr_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) referredtoidentifierattribute.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) referredtoidentifierattribute.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) referredtoidentifierattribute.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setOid_ID( int ref_Oid_ID ) throws XtumlException {
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) referredtoidentifierattribute.setOid_ID( ref_Oid_ID );
    }


    // selections
    @Override
    public ReferredToClassInAssocSet R110_identifies_for_this_association_ReferredToClassInAssoc() throws XtumlException {
        ReferredToClassInAssocSet referredtoclassinassocset = new ReferredToClassInAssocSetImpl();
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) referredtoclassinassocset.add( referredtoidentifierattribute.R110_identifies_for_this_association_ReferredToClassInAssoc() );
        return referredtoclassinassocset;
    }
    @Override
    public ClassIdentifierAttributeSet R110_is_identified_in_this_association_by_ClassIdentifierAttribute() throws XtumlException {
        ClassIdentifierAttributeSet classidentifierattributeset = new ClassIdentifierAttributeSetImpl();
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) classidentifierattributeset.add( referredtoidentifierattribute.R110_is_identified_in_this_association_by_ClassIdentifierAttribute() );
        return classidentifierattributeset;
    }
    @Override
    public AttributeReferenceInClassSet R111_is_used_to_refer_class_by_AttributeReferenceInClass() throws XtumlException {
        AttributeReferenceInClassSet attributereferenceinclassset = new AttributeReferenceInClassSetImpl();
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) attributereferenceinclassset.addAll( referredtoidentifierattribute.R111_is_used_to_refer_class_by_AttributeReferenceInClass() );
        return attributereferenceinclassset;
    }


    @Override
    public ReferredToIdentifierAttribute nullElement() {
        return ReferredToIdentifierAttributeImpl.EMPTY_REFERREDTOIDENTIFIERATTRIBUTE;
    }

    @Override
    public ReferredToIdentifierAttributeSet emptySet() {
      return new ReferredToIdentifierAttributeSetImpl();
    }

    @Override
    public ReferredToIdentifierAttributeSet value() {
        return this;
    }

    @Override
    public List<ReferredToIdentifierAttribute> elements() {
        return Arrays.asList(toArray(new ReferredToIdentifierAttribute[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/ReferredToIdentifierAttributeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferredToClassInAssocSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.AttributeReferenceInClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ClassIdentifierAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferredToIdentifierAttribute;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferredToIdentifierAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.AttributeReferenceInClassSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ClassIdentifierAttributeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ReferredToIdentifierAttributeSetImpl extends InstanceSet<ReferredToIdentifierAttributeSet,ReferredToIdentifierAttribute> implements ReferredToIdentifierAttributeSet {

    public ReferredToIdentifierAttributeSetImpl() {
    }

    public ReferredToIdentifierAttributeSetImpl(Comparator<? super ReferredToIdentifierAttribute> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) referredtoidentifierattribute.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setOid_ID( int ref_Oid_ID ) throws XtumlException {
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) referredtoidentifierattribute.setOid_ID( ref_Oid_ID );
    }
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) referredtoidentifierattribute.setAttr_ID( ref_Attr_ID );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) referredtoidentifierattribute.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) referredtoidentifierattribute.setOIR_ID( ref_OIR_ID );
    }


    // selections
    @Override
    public ReferredToClassInAssocSet R110_identifies_for_this_association_ReferredToClassInAssoc() throws XtumlException {
        ReferredToClassInAssocSet referredtoclassinassocset = new ReferredToClassInAssocSetImpl();
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) referredtoclassinassocset.add( referredtoidentifierattribute.R110_identifies_for_this_association_ReferredToClassInAssoc() );
        return referredtoclassinassocset;
    }
    @Override
    public ClassIdentifierAttributeSet R110_is_identified_in_this_association_by_ClassIdentifierAttribute() throws XtumlException {
        ClassIdentifierAttributeSet classidentifierattributeset = new ClassIdentifierAttributeSetImpl();
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) classidentifierattributeset.add( referredtoidentifierattribute.R110_is_identified_in_this_association_by_ClassIdentifierAttribute() );
        return classidentifierattributeset;
    }
    @Override
    public AttributeReferenceInClassSet R111_is_used_to_refer_class_by_AttributeReferenceInClass() throws XtumlException {
        AttributeReferenceInClassSet attributereferenceinclassset = new AttributeReferenceInClassSetImpl();
        for ( ReferredToIdentifierAttribute referredtoidentifierattribute : this ) attributereferenceinclassset.addAll( referredtoidentifierattribute.R111_is_used_to_refer_class_by_AttributeReferenceInClass() );
        return attributereferenceinclassset;
    }


    @Override
    public ReferredToIdentifierAttribute nullElement() {
        return ReferredToIdentifierAttributeImpl.EMPTY_REFERREDTOIDENTIFIERATTRIBUTE;
    }

    @Override
    public ReferredToIdentifierAttributeSet emptySet() {
      return new ReferredToIdentifierAttributeSetImpl();
    }

    @Override
    public ReferredToIdentifierAttributeSet emptySet(Comparator<? super ReferredToIdentifierAttribute> comp) {
      return new ReferredToIdentifierAttributeSetImpl(comp);
    }

    @Override
    public ReferredToIdentifierAttributeSet value() {
        return this;
    }

    @Override
    public List<ReferredToIdentifierAttribute> elements() {
        return Arrays.asList(toArray(new ReferredToIdentifierAttribute[0]));
    }

}
